@@ -5,6 +5,7 @@
 # Do not include any function in here that does not correspond to a COMMAND
 
 import os
+import re
 import inspect
 import tempfile
 import subprocess
@@ -24,6 +25,8 @@ from wajig.constants import APP, VERSION
 # before we do any other command make sure the right files exist
 util.ensure_initialised()
 
+NO_UPGRADES = 'No packages need to be upgraded. Run "wajig update" to update from the repository.'
+
 
 def addcdrom(args):
     """Add a Debian CD/DVD to APT's list of available sources"""
@@ -247,7 +250,7 @@ def distupgrade(args):
     """
     packages = util.upgradable(distupgrade=True)
     if not packages and not args.dist:
-        print('No upgrades. Did you run "wajig update" beforehand?')
+        print(NO_UPGRADES)
         return
     if args.backup:
         util.requires_package("dpkg-repack")
@@ -731,9 +734,10 @@ def reboot(args):
         cmd = f"test -f {PKGS}"
         result = perform.execute(cmd)
         if result == 0:
-            print("\nThe following packages necessitate the reboot:")
+            print("\nThe following packages necessitate the reboot:\n")
             cmd = f"cat {PKGS} | perl -p -e 's|^|  |'"
             perform.execute(cmd)
+            print()
         print('To reboot use "sudo reboot"')
     else:
         print('A reboot is not required.')
@@ -951,7 +955,9 @@ def sysinfo(args):
     result  = perform.execute(command, getoutput=True).decode("utf-8").strip()
     command = "cat /proc/cpuinfo | grep 'process'| wc -l"
     count   = perform.execute(command, getoutput=True).decode("utf-8").strip()
-    print(f"Processor:  {result} x {count}")
+    command = "cat /proc/cpuinfo | grep bogomips | uniq | sed 's|bogomips\t:||'"
+    bogomip = perform.execute(command, getoutput=True).decode("utf-8").strip()
+    print(f"Processor:  {result} x {count} = {bogomip} bogomips")
 
     command =  'GPU=$(lspci | grep VGA | cut -d ":" -f3); '
     command += 'RAM=$(cardid=$(lspci | grep VGA |cut -d " " -f1); '
@@ -964,24 +970,26 @@ def sysinfo(args):
     result  = perform.execute(command, getoutput=True).decode("utf-8").strip()
     print(f"Audio:      {result}")
     
-    command = "cat /proc/cpuinfo | grep bogomips | uniq | sed 's|bogomips\t:||'"
-    result  = perform.execute(command, getoutput=True).decode("utf-8").strip()
-    print(f"BogoMIPS:   {result}")
-
     command = "cat /proc/meminfo | grep MemTotal | awk '{print $2/(1024*1024)}'"
     result  = perform.execute(command, getoutput=True).decode("utf-8").strip()
-    print(f"RAM:        {round(float(result))}GB")
+    print(f"Memory:     {round(float(result))}GB RAM")
 
     command = "cat /etc/*release | grep '^NAME=' | cut -d '\"' -f2"
     result  = perform.execute(command, getoutput=True).decode("utf-8").strip()
     command = "cat /etc/*release | grep '^VERSION=' | cut -d '\"' -f2"
     ver  = perform.execute(command, getoutput=True).decode("utf-8").strip()
-    print(f"Base OS:    {result} {ver}")
+    print(f"OS:         {result} {ver}")
 
     command = "uname -r"
     result  = perform.execute(command, getoutput=True).decode("utf-8").strip()
     print(f"Kernel:     {result}")
 
+    command = "uptime --pretty"
+    up  = perform.execute(command, getoutput=True).decode("utf-8").strip()
+    command = "uptime --since"
+    since  = perform.execute(command, getoutput=True).decode("utf-8").strip()
+    print(f"Uptime:     {up} since {since}")
+    
 def tasksel(args):
     """Run the task selector to install groups of packages"""
     util.requires_package("tasksel")
@@ -996,7 +1004,7 @@ def todo(args):
 def toupgrade(args):
     """List versions of upgradable packages"""
     if not util.show_package_versions():
-        print("No upgradeable packages")
+        print("No upgradeable packages.")
 
 
 def tutorial(args):
@@ -1028,7 +1036,7 @@ def unofficial(args):
 
 
 def update(args):
-    """Update the list of new and updated packages"""
+    """Update the list of new and updated packages available from the repository"""
     util.do_update(args.simulate)
 
 
@@ -1069,7 +1077,7 @@ def upgrade(args):
         command = command.format(args.local, args.yes, args.noauth)
         perform.execute(command, root=True, log=True)
     else:
-        print('No upgradeable packages. Did you run "wajig update" first?')
+        print(NO_UPGRADES)
 
 
 def upgradesecurity(args):
